@@ -22,7 +22,6 @@ import math
 import numbers
 from copy import deepcopy
 import hashlib
-import pyaes
 import unicodedata
 from bitcoinlib.main import *
 _logger = logging.getLogger(__name__)
@@ -30,20 +29,32 @@ _logger = logging.getLogger(__name__)
 
 SCRYPT_ERROR = None
 USING_MODULE_SCRYPT = os.getenv("USING_MODULE_SCRYPT") not in ["false", "False", "0", "FALSE"]
+
+try:
+    from Crypto.Cipher import AES
+except ImportError as PYAES_ERROR:
+    _logger.warning("MISSING MODULES! Please install pycryptodome")
+    _logger.warning("The bip38_decrypt and bip38_encrypt methods need the pycryptodome library to work!")
+
 try:
     if USING_MODULE_SCRYPT is not False:
         import scrypt
         USING_MODULE_SCRYPT = True
 except ImportError as SCRYPT_ERROR:
-    pass
+    from Crypto.Protocol.KDF import scrypt
+
 if 'scrypt' not in sys.modules:
-    import pyscrypt as scrypt
+    try:
+        import pyscrypt as scrypt
+    except ImportError:
+        _logger.warning("MISSING MODULES! Please install scrypt, pycryptodome or pyscrypt")
+        _logger.warning("The bip38_decrypt and bip38_encrypt methods need a scrypt library to work!")
     USING_MODULE_SCRYPT = False
 
 if not USING_MODULE_SCRYPT:
     if 'scrypt_error' not in locals():
         SCRYPT_ERROR = 'unknown'
-    _logger.warning("Error when trying to import scrypt module %s" % SCRYPT_ERROR)
+    _logger.warning("Error when trying to import scrypt module. Error message: %s" % SCRYPT_ERROR)
 
 USE_FASTECDSA = os.getenv("USE_FASTECDSA") not in ["false", "False", "0", "FALSE"]
 try:
@@ -173,7 +184,7 @@ def change_base(chars, base_from, base_to, min_length=0, output_even=None, outpu
     :param chars: Input string
     :type chars: any
     :param base_from: Base number or name from input. For example 2 for binary, 10 for decimal and 16 for hexadecimal
-    :type base_from: int
+    :type base_from: int, str
     :param base_to: Base number or name for output. For example 2 for binary, 10 for decimal and 16 for hexadecimal
     :type base_to: int
     :param min_length: Minimal output length. Required for decimal, advised for all output to avoid leading zeros conversion problems.
@@ -216,6 +227,10 @@ def change_base(chars, base_from, base_to, min_length=0, output_even=None, outpu
         return int.from_bytes(inp, 'big')
     if base_from == 10 and base_to == 256:
         return inp.to_bytes(min_length, byteorder='big')
+    if base_from == 256 and base_to == 58:
+        return base58encode(inp)
+    if base_from == 16 and base_to == 58:
+        return base58encode(bytes.fromhex(chars))
 
     if output_even is None and base_to == 16:
         output_even = True
@@ -284,13 +299,7 @@ def change_base(chars, base_from, base_to, min_length=0, output_even=None, outpu
             output = [code_str[0]] + output
 
     if not output_as_list and isinstance(output, list):
-        if len(output) == 0:
-            output = 0
-        else:
-            co = ''
-            for c in output:
-                co += chr(c)
-            output = co
+        output = 0 if not len(output) else ''.join([chr(c) for c in output])
     if base_to == 10:
         return int(0) or (output != '' and int(output))
     if base_to == 256 and not output_as_list:
@@ -299,6 +308,28 @@ def change_base(chars, base_from, base_to, min_length=0, output_even=None, outpu
         return output
 
 
+def base58encode(inp):
+    """
+    Convert bytes to base58 encode string
+
+    :param inp: Input string
+    :type inp: bytes
+
+    :return str:
+    """
+    origlen = len(inp)
+    inp = inp.lstrip(b'\0')
+    padding_zeros = origlen - len(inp)
+    code_str = '123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz'
+    acc = int.from_bytes(inp, 'big')
+
+    string = ''
+    while acc:
+        acc, idx = divmod(acc, 58)
+        string = code_str[idx:idx + 1] + string
+    return '1' * padding_zeros + string
+
+
 def varbyteint_to_int(byteint):
     """
     Convert CompactSize Variable length integer in byte format to integer.
@@ -316,7 +347,7 @@ def varbyteint_to_int(byteint):
     if not isinstance(byteint, (bytes, list)):
         raise EncodingError("Byteint must be a list or defined as bytes")
     if byteint == b'':
-        return 0
+        return 0, 0
     ni = byteint[0]
     if ni < 253:
         return ni, 1
@@ -344,6 +375,36 @@ def read_varbyteint(s):
     return value
 
 
+def read_varbyteint_return(s):
+    """
+    Read variable length integer from BytesIO stream. Return original converted bytes (to reconstruct transaction or
+    script).
+
+    :param s: A binary stream
+    :type s: BytesIO
+
+    :return (int, bytes):
+    """
+    pos = s.tell()
+    byteint = s.read(9)
+    if not byteint:
+        return 0, b''
+
+    ni = byteint[0]
+    if ni < 253:
+        s.seek(pos + 1)
+        return ni, byteint[0:1]
+    if ni == 253:  # integer of 2 bytes
+        size = 2
+    elif ni == 254:  # integer of 4 bytes
+        size = 4
+    else:  # integer of 8 bytes
+        size = 8
+    varbytes = byteint[1:1+size]
+    s.seek(pos + size + 1)
+    return int.from_bytes(varbytes[::-1], 'big'), byteint[0:1] + varbytes
+
+
 def int_to_varbyteint(inp):
     """
     Convert integer to CompactSize Variable length integer in byte format.
@@ -504,12 +565,16 @@ def addr_bech32_to_pubkeyhash(bech, prefix=None, include_witver=False, as_hex=Fa
         raise EncodingError("Invalid bech32 string length")
     if prefix and prefix != bech[:pos]:
         raise EncodingError("Invalid bech32 address. Prefix '%s', prefix expected is '%s'" % (bech[:pos], prefix))
-    else:
-        hrp = bech[:pos]
+    hrp = bech[:pos]
     data = _codestring_to_array(bech[pos + 1:], 'bech32')
     hrp_expanded = [ord(x) >> 5 for x in hrp] + [0] + [ord(x) & 31 for x in hrp]
-    if not _bech32_polymod(hrp_expanded + data) == 1:
+    check = _bech32_polymod(hrp_expanded + data)
+    if not (check == 1 or check == BECH32M_CONST):
         raise EncodingError("Bech polymod check failed")
+    if data[0] == 0 and check != 1:
+        raise EncodingError("Invalid checksum (Bech32m instead of Bech32)")
+    if data[0] != 0 and check != BECH32M_CONST:
+        raise EncodingError("Invalid checksum (Bech32 instead of Bech32m)")
     data = data[:-6]
     decoded = bytes(convertbits(data[1:], 5, 8, pad=False))
     if decoded is None or len(decoded) < 2 or len(decoded) > 40:
@@ -527,6 +592,28 @@ def addr_bech32_to_pubkeyhash(bech, prefix=None, include_witver=False, as_hex=Fa
     return prefix + decoded
 
 
+def addr_bech32_checksum(bech):
+    """
+    Get bech32 checksum. Returns 1 for bech32 addresses and 0x2bc830a3 for bech32m addresses.
+    More info https://github.com/bitcoin/bips/blob/master/bip-0350.mediawiki
+
+    >>> addr_bech32_checksum('bc1pw508d6qejxtdg4y5r3zarvary0c5xw7kw508d6qejxtdg4y5r3zarvary0c5xw7kt5nd6y')
+    734539939
+
+    :param bech: Bech32 address to convert
+    :type bech: str
+
+    :return bool: Bech32 checksum
+    """
+
+    bech = bech.lower()
+    pos = bech.rfind('1')
+    hrp = bech[:pos]
+    data = _codestring_to_array(bech[pos + 1:], 'bech32')
+    hrp_expanded = [ord(x) >> 5 for x in hrp] + [0] + [ord(x) & 31 for x in hrp]
+    return _bech32_polymod(hrp_expanded + data)
+
+
 def pubkeyhash_to_addr(pubkeyhash, prefix=None, encoding='base58'):
     """
     Convert public key hash to base58 encoded address
@@ -571,10 +658,10 @@ def pubkeyhash_to_addr_base58(pubkeyhash, prefix=b'\x00'):
     """
     key = to_bytes(prefix) + to_bytes(pubkeyhash)
     addr256 = key + double_sha256(key)[:4]
-    return change_base(addr256, 256, 58)
+    return base58encode(addr256)
 
 
-def pubkeyhash_to_addr_bech32(pubkeyhash, prefix='bc', witver=0, separator='1'):
+def pubkeyhash_to_addr_bech32(pubkeyhash, prefix='bc', witver=0, separator='1', checksum_xor=1):
     """
     Encode public key hash as bech32 encoded (segwit) address
 
@@ -608,7 +695,7 @@ def pubkeyhash_to_addr_bech32(pubkeyhash, prefix='bc', witver=0, separator='1'):
 
     # Expand the HRP into values for checksum computation
     hrp_expanded = [ord(x) >> 5 for x in prefix] + [0] + [ord(x) & 31 for x in prefix]
-    polymod = _bech32_polymod(hrp_expanded + data + [0, 0, 0, 0, 0, 0]) ^ 1
+    polymod = _bech32_polymod(hrp_expanded + data + [0, 0, 0, 0, 0, 0]) ^ checksum_xor
     checksum = [(polymod >> 5 * (5 - i)) & 31 for i in range(6)]
 
     return prefix + separator + _array_to_codestring(data, 'bech32') + _array_to_codestring(checksum, 'bech32')
@@ -817,7 +904,8 @@ def bip38_decrypt(encrypted_privkey, password):
     derivedhalf2 = key[32:64]
     encryptedhalf1 = d[0:16]
     encryptedhalf2 = d[16:32]
-    aes = pyaes.AESModeOfOperationECB(derivedhalf2)
+    # aes = pyaes.AESModeOfOperationECB(derivedhalf2)
+    aes = AES.new(derivedhalf2, AES.MODE_ECB)
     decryptedhalf2 = aes.decrypt(encryptedhalf2)
     decryptedhalf1 = aes.decrypt(encryptedhalf1)
     priv = decryptedhalf1 + decryptedhalf2
@@ -852,14 +940,15 @@ def bip38_encrypt(private_hex, address, password, flagbyte=b'\xe0'):
     key = scrypt.hash(password, addresshash, 16384, 8, 8, 64)
     derivedhalf1 = key[0:32]
     derivedhalf2 = key[32:64]
-    aes = pyaes.AESModeOfOperationECB(derivedhalf2)
+    aes = AES.new(derivedhalf2, AES.MODE_ECB)
+    # aes = pyaes.AESModeOfOperationECB(derivedhalf2)
     encryptedhalf1 = \
         aes.encrypt((int(private_hex[0:32], 16) ^ int.from_bytes(derivedhalf1[0:16], 'big')).to_bytes(16, 'big'))
     encryptedhalf2 = \
         aes.encrypt((int(private_hex[32:64], 16) ^ int.from_bytes(derivedhalf1[16:32], 'big')).to_bytes(16, 'big'))
     encrypted_privkey = b'\x01\x42' + flagbyte + addresshash + encryptedhalf1 + encryptedhalf2
     encrypted_privkey += double_sha256(encrypted_privkey)[:4]
-    return change_base(encrypted_privkey, 256, 58)
+    return base58encode(encrypted_privkey)
 
 
 class Quantity:
@@ -889,12 +978,12 @@ class Quantity:
         # Metric prefixes according to BIPM, the International System of Units (SI) in 10**3 steps
         self.prefix_list = list('yzafpnμm1kMGTPEZY')
         self.base = self.prefix_list.index('1')
-        assert value > 0
+        assert value >= 0
 
         self.absolute = value
         self.units = units
         self.precision = precision
-        while (value < 1 or value > 1000) and 0 < self.base < len(self.prefix_list)-1:
+        while value != 0 and (value < 1 or value > 1000) and 0 < self.base < len(self.prefix_list)-1:
             if value > 1000:
                 self.base += 1
                 value /= 1000.0
@@ -905,4 +994,7 @@ class Quantity:
 
     def __str__(self):
         # > Python 3.6: return f"{self.value:4.{self.precision}f} {self.prefix_list[self.base]}{self.units}"
-        return '%4.*f %s%s' % (self.precision, self.value, self.prefix_list[self.base], self.units)
+        prefix = self.prefix_list[self.base]
+        if prefix == '1':
+            prefix = ''
+        return ('%4.*f %s%s' % (self.precision, self.value, prefix, self.units)).strip()
