@@ -46,17 +46,11 @@ class BcoinClient(BaseClient):
             variables = {}
         return self.request(url_path, variables, method, secure=False)
 
-    def _parse_transaction(self, tx, strict=True):
+    def _parse_transaction(self, tx):
         status = 'unconfirmed'
         if tx['confirmations']:
             status = 'confirmed'
         t = Transaction.parse_hex(tx['hex'], strict=False, network=self.network)
-        if not t.txid == tx['hash']:
-            if strict:
-                raise ClientError('Received transaction has different txid')
-            else:
-                t.txid = tx['hash']
-                _logger.warning('Received transaction has different txid')
         t.locktime = tx['locktime']
         t.network = self.network
         t.fee = tx['fee']
@@ -161,7 +155,7 @@ class BcoinClient(BaseClient):
         res = self.compose_request('broadcast', variables={'tx': rawtx}, method='post')
         txid = ''
         if 'success' in res and res['success']:
-            t = Transaction.parse_hex(rawtx, strict=False, network=self.network)
+            t = Transaction.parse_hex(rawtx, network=self.network)
             txid = t.txid
         return {
             'txid': txid,
@@ -201,8 +195,7 @@ class BcoinClient(BaseClient):
             tx['height'] = block['height']
             tx['block'] = block['hash']
             if parse_transactions:
-                # FIXME: Parse all transactions as strict=True
-                t = self._parse_transaction(tx, strict=False)
+                t = self._parse_transaction(tx)
                 parsed_txs.append(t)
             else:
                 parsed_txs.append(tx['hash'])
@@ -217,7 +210,20 @@ class BcoinClient(BaseClient):
         block['block_hash'] = block.pop('hash')
         return block
 
-    # def getrawblock
+    def getrawblock(self, blockid):
+        try:
+            blockid = int(blockid)
+            data = {
+                "method": "getblockbyheight",
+                "params": [blockid, 0, 0]
+            }
+        except ValueError:
+            data = {
+                "method": "getblock",
+                "params": [blockid, 0, 0]
+            }
+        res = self.compose_request('', method='post', variables=data)
+        return res['result']
 
     def isspent(self, txid, index):
         try:
