@@ -78,7 +78,7 @@ class BlockchainInfoClient(BaseClient):
     def gettransaction(self, txid, latest_block=None):
         tx = self.compose_request('rawtx', txid)
         rawtx = self.getrawtransaction(txid)
-        t = Transaction.parse_hex(rawtx, strict=False, network=self.network)
+        t = Transaction.parse_hex(rawtx, strict=self.strict, network=self.network)
         input_total = 0
         for n, i in enumerate(t.inputs):
             if 'prev_out' in tx['inputs'][n]:
