@@ -18,7 +18,6 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import math
 import logging
 from datetime import datetime
 try:
@@ -136,12 +135,12 @@ class BlockChairClient(BaseClient):
                 t.add_input(prev_txid=ti['transaction_hash'], output_n=ti['index'],
                             unlocking_script=ti['spending_signature_hex'],
                             witnesses=witnesses, index_n=index_n, value=ti['value'],
-                            address=address, witness_type=witness_type, sequence=ti['spending_sequence'], strict=False)
+                            address=address, witness_type=witness_type, sequence=ti['spending_sequence'], strict=self.strict)
             else:
                 t.add_input(prev_txid=ti['transaction_hash'], output_n=ti['index'],
                             unlocking_script=ti['spending_signature_hex'], index_n=index_n, value=ti['value'],
                             address=ti['recipient'], unlocking_script_unsigned=ti['script_hex'],
-                            sequence=ti['spending_sequence'], strict=False)
+                            sequence=ti['spending_sequence'], strict=self.strict)
             index_n += 1
         for to in res['data'][tx_id]['outputs']:
             try:
@@ -151,7 +150,7 @@ class BlockChairClient(BaseClient):
                 addr = ''
             t.add_output(value=to['value'], address=addr, lock_script=to['script_hex'],
                          spent=to['is_spent'], output_n=to['index'], spending_txid=to['spending_transaction_hash'],
-                         spending_index_n=to['spending_index'], strict=False)
+                         spending_index_n=to['spending_index'], strict=self.strict)
         return t
 
     def gettransactions(self, address, after_txid='', limit=MAX_TRANSACTIONS):
