@@ -72,13 +72,13 @@ class InsightDashClient(BaseClient):
                 t.add_input(prev_txid=ti['txid'], output_n=ti['vout'], unlocking_script=ti['scriptSig']['hex'],
                             index_n=ti['n'], value=value, sequence=ti['sequence'],
                             double_spend=False if ti['doubleSpentTxID'] is None else ti['doubleSpentTxID'],
-                            strict=False)
+                            strict=self.strict)
         for to in tx['vout']:
             value = int(round(float(to['value']) * self.units, 0))
             t.add_output(value=value, lock_script=to['scriptPubKey']['hex'],
                          spent=True if to['spentTxId'] else False, output_n=to['n'],
                          spending_txid=None if not to['spentTxId'] else to['spentTxId'],
-                         spending_index_n=None if not to['spentIndex'] else to['spentIndex'], strict=False)
+                         spending_index_n=None if not to['spentIndex'] else to['spentIndex'], strict=self.strict)
         return t
 
     def getbalance(self, addresslist):
