@@ -27,3 +27,5 @@ import tests.test_services
 import tests.test_tools
 import tests.test_db
 import tests.test_blocks
+import tests.test_values
+import tests.test_script
