@@ -19,7 +19,7 @@
 #
 
 import unittest
-from datetime import datetime
+import logging
 try:
     import mysql.connector
     from parameterized import parameterized_class
@@ -35,6 +35,7 @@ from bitcoinlib.services.services import *
 from bitcoinlib.encoding import to_hexstring
 from tests.test_custom import CustomAssertions
 
+_logger = logging.getLogger(__name__)
 MAXIMUM_ESTIMATED_FEE_DIFFERENCE = 3.00  # Maximum difference from average estimated fee before test_estimatefee fails.
 # Use value above >0, and 1 for 100%
 
@@ -42,12 +43,16 @@ DATABASEFILE_CACHE_UNITTESTS = os.path.join(str(BCL_DATABASE_DIR), 'bitcoinlibca
 DATABASEFILE_CACHE_UNITTESTS2 = os.path.join(str(BCL_DATABASE_DIR), 'bitcoinlibcache2.unittest.sqlite')
 DATABASE_CACHE_POSTGRESQL = 'postgresql://postgres:postgres@localhost:5432/bitcoinlibcache.unittest'
 # FIXME: MySQL databases are not supported. Not allowed to create indexes/primary keys on binary fields
-# DATABASE_CACHE_MYSQL = 'mysql://root@localhost:3306/bitcoinlibcache.unittest'
+DATABASE_CACHE_MYSQL = 'mysql://root:root@localhost:3306/bitcoinlibcache.unittest'
 DATABASES_CACHE = [
     DATABASEFILE_CACHE_UNITTESTS2,
-    DATABASE_CACHE_POSTGRESQL,
-    # DATABASE_CACHE_MYSQL
 ]
+if UNITTESTS_FULL_DATABASE_TEST:
+    DATABASES_CACHE += [
+        DATABASE_CACHE_POSTGRESQL,
+        DATABASE_CACHE_MYSQL
+    ]
+
 TIMEOUT_TEST = 2
 
 
@@ -56,9 +61,9 @@ class ServiceTest(Service):
 
     def __init__(self, network=DEFAULT_NETWORK, min_providers=1, max_providers=1, providers=None,
                  timeout=TIMEOUT_TEST, cache_uri=DATABASEFILE_CACHE_UNITTESTS, ignore_priority=True,
-                 exclude_providers=None):
+                 exclude_providers=None, max_errors=SERVICE_MAX_ERRORS, strict=True):
         super(self.__class__, self).__init__(network, min_providers, max_providers, providers, timeout, cache_uri,
-                                             ignore_priority, exclude_providers)
+                                             ignore_priority, exclude_providers, max_errors, strict)
 
 
 class TestService(unittest.TestCase, CustomAssertions):
@@ -151,16 +156,10 @@ class TestService(unittest.TestCase, CustomAssertions):
                 prev = balance
 
     def test_service_address_conversion(self):
-        srv = ServiceTest(min_providers=2, network='litecoin_legacy', providers=['cryptoid', 'litecoreio'])
-        try:
-            srv.getbalance('3N59KFZBzpnq4EoXo2cDn2GKjX1dfkv1nB')
-            exp_dict = {'cryptoid.litecoin.legacy': 95510000, 'litecoreio.litecoin.legacy': 95510000}
-            for r in srv.results:
-                if r not in exp_dict:
-                    print("WARNING: Provider %s not found in results" % r)
-                self.assertEqual(srv.results[r], exp_dict[r])
-        except ServiceError:
-            self.skipTest("No response from service providers")
+        srv = ServiceTest(min_providers=2, network='litecoin_legacy')
+        srv.getbalance('3N59KFZBzpnq4EoXo2cDn2GKjX1dfkv1nB')
+        for r in srv.results:
+            self.assertEqual(srv.results[r], 95510000)
 
     def test_service_get_utxos(self):
         expected_dict = {
@@ -528,7 +527,6 @@ class TestService(unittest.TestCase, CustomAssertions):
             'date': datetime(2017, 12, 24, 13, 16, 30),
             'flag': 1,
             'hash': '68104dbd6819375e7bdf96562f89290b41598df7b002089ecdd3c8d999025b13',
-            'input_total': 0,
             'inputs': [
                 {'address': '',
                  'index_n': 0,
@@ -570,7 +568,7 @@ class TestService(unittest.TestCase, CustomAssertions):
         srv.gettransaction('68104dbd6819375e7bdf96562f89290b41598df7b002089ecdd3c8d999025b13')
 
         for provider in srv.results:
-            print("Comparing provider %s" % provider)
+            _logger.info("Comparing provider %s" % provider)
             for o in srv.results[provider].outputs:
                 if o.spending_txid == '':
                     o.spending_txid = None
@@ -637,7 +635,7 @@ class TestService(unittest.TestCase, CustomAssertions):
 
     def test_service_gettransaction_segwit_coinbase(self):
         txid = 'ed7e0ecceb6c4d6f10ca935d8dc037921f9855fd46a2e51d82f76dd5ec564a3a'
-        srv = ServiceTest(network='bitcoin')
+        srv = ServiceTest(network='bitcoin', strict=False)
         t = srv.gettransaction(txid)
         self.assertTrue(t.verify())
         self.assertTrue(t.inputs[0].valid)
@@ -694,7 +692,7 @@ class TestService(unittest.TestCase, CustomAssertions):
 
     def test_service_mempool(self):
         txid = 'ed7e0ecceb6c4d6f10ca935d8dc037921f9855fd46a2e51d82f76dd5ec564a3a'
-        srv = ServiceTest(min_providers=3)
+        srv = ServiceTest(min_providers=10)
         srv.mempool(txid)
         for provider in srv.results:
             # print("Mempool: Comparing btc provider %s" % provider)
